/** @module project/state */

/**
 * state.js
 *
 * Collection of everything which has to do with state changes.
 * - actionTypes
 * - actions
 **/

import combineReducers from 'redux'
import reduxCrudGen from 'redux-gen/crud'
import reduxGen from 'redux-gen/basic'
import { NAME, DATA } from './constants'
// import { call, put, takeEvery } from 'redux-saga/effects'

const basic = reduxGen(NAME)
const crud = reduxCrudGen(NAME)

/** actionTypes define what actions are handeled by the reducer. */
const actions = { ...basic.actions, ...crud.actions }
console.log('State actions', actions)

/** state definition */
/** It is generally easier to not have another object here. */
export const state = [ ...basic.state, ...crud.state ]
console.log('State state', state)

/** reducer is called by the redux dispatcher and handles all component actions */
export function reducer (state = [], action) {
  let nextState
  nextState = basic.reducer(state, action)
  nextState = crud.reducer(nextState, action)
  return nextState
}

/** sagas are asynchronous workers (JS generators) to handle the state. */
export const workers = crud.workers

// Watcher (intercepts INCREMENT_REQUEST, dispatches INCREMENT_SUCCESS or INCREMENT_FAIL in return.)
export const watchers = crud.watchers
